@@ -18,7 +18,7 @@ from oslo_config import cfg
 from sahara import context
 import sahara.exceptions as ex
 from sahara.i18n import _
-import sahara.service.api as api
+from sahara.service.api import v10 as api
 from sahara.service.health import verification_base
 from sahara.service.validations import acl
 import sahara.service.validations.base as b
@@ -41,16 +41,22 @@ def check_multiple_clusters_create(data, **kwargs):
 
 
 def _check_cluster_create(data):
+    plugin_version = 'hadoop_version'
+    if data.get('plugin_version'):
+        plugin_version = 'plugin_version'
     b.check_plugin_name_exists(data['plugin_name'])
     b.check_plugin_supports_version(data['plugin_name'],
-                                    data['hadoop_version'])
+                                    data[plugin_version])
+    b.check_plugin_labels(
+        data['plugin_name'], data[plugin_version])
+
     if data.get('cluster_template_id'):
         ct_id = data['cluster_template_id']
         b.check_cluster_template_exists(ct_id)
         if not data.get('node_groups'):
             b.check_node_groups_in_cluster_templates(data['name'],
                                                      data['plugin_name'],
-                                                     data['hadoop_version'],
+                                                     data[plugin_version],
                                                      ct_id)
 
     if data.get('user_keypair_id'):
@@ -60,7 +66,7 @@ def _check_cluster_create(data):
     if default_image_id:
         b.check_image_registered(default_image_id)
         b.check_required_image_tags(data['plugin_name'],
-                                    data['hadoop_version'],
+                                    data[plugin_version],
                                     default_image_id)
     else:
         raise ex.NotFoundException('default_image_id',
@@ -69,13 +75,10 @@ def _check_cluster_create(data):
     b.check_all_configurations(data)
 
     if data.get('anti_affinity'):
-        b.check_node_processes(data['plugin_name'], data['hadoop_version'],
+        b.check_node_processes(data['plugin_name'], data[plugin_version],
                                data['anti_affinity'])
 
     if data.get('node_groups'):
-        proxy_gateway_used = len([ng for ng in data['node_groups'] if
-                                  ng.get('is_proxy_gateway', False)]) > 0
-        b.check_network_config(data['node_groups'], proxy_gateway_used)
         b.check_cluster_hostnames_lengths(data['name'], data['node_groups'])
 
     neutron_net_id = _get_cluster_field(data, 'neutron_management_network')
